@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -28,9 +28,7 @@
 # SOFTWARE.
 ###############################################################################
 
-"""
-TODO
-"""
+"""This module handles encryption logic"""
 
 import logging
 import os
@@ -40,6 +38,10 @@ from cryptography.fernet import Fernet
 from merlin.config.configfile import CONFIG
 
 
+# This disables all the errors about short variable names (like using f to represent a file)
+# pylint: disable=invalid-name
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -52,8 +54,8 @@ def _get_key_path():
 
     try:
         key_filepath = os.path.abspath(os.path.expanduser(key_filepath))
-    except KeyError:
-        raise ValueError("Error! No password provided for RabbitMQ")
+    except KeyError as e:
+        raise ValueError("Error! No password provided for RabbitMQ") from e
     return key_filepath
 
 
