@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -38,7 +38,10 @@ from typing import Dict, List, Optional
 from merlin.utils import nested_dict_to_namespaces
 
 
-class Config:
+# Pylint complains that there's too few methods here but this class might
+# be useful if we ever need to do extra stuff with the configuration so we'll
+# ignore it for now
+class Config:  # pylint: disable=R0903
     """
     The Config class, meant to store all Merlin config settings in one place.
     Regardless of the config data loading method, this class is meant to
