@@ -1,5 +1,6 @@
 import argparse
 import json
+import sys
 
 
 def process_args(args):
@@ -25,9 +26,14 @@ def setup_argparse():
 
 
 def main():
-    parser = setup_argparse()
-    args = parser.parse_args()
-    process_args(args)
+    try:
+        parser = setup_argparse()
+        args = parser.parse_args()
+        process_args(args)
+        sys.exit()
+    except Exception as ex:
+        print(ex)
+        sys.exit(1)
 
 
 if __name__ == "__main__":
