@@ -37,13 +37,18 @@ def setup_argparse():
 
 
 def main():
-    parser = setup_argparse()
-    args = parser.parse_args()
+    try:
+        parser = setup_argparse()
+        args = parser.parse_args()
 
-    # Collect sample files into single file
-    sample_paths = [sample_path for sample_path in args.sample_file_paths]
-    serialize_samples(sample_paths, args.outfile, args.np)
+        # Collect sample files into single file
+        sample_paths = [sample_path for sample_path in args.sample_file_paths]
+        serialize_samples(sample_paths, args.outfile, args.np)
+        sys.exit()
+    except Exception as ex:
+        print(ex)
+        sys.exit(1)
 
 
 if __name__ == "__main__":
-    sys.exit(main())
+    main()
