@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -42,12 +42,14 @@ from merlin.log_formatter import setup_logging
 LOG = logging.getLogger("merlin-templates")
 DEFAULT_LOG_LEVEL = "ERROR"
 
+# We disable all pylint errors in this file since this is deprecated anyways
 
-def process_templates(args):
+
+def process_templates(args):  # pylint: disable=W0613,C0116
     LOG.error("The command `merlin-templates` has been deprecated in favor of `merlin example`.")
 
 
-def setup_argparse():
+def setup_argparse():  # pylint: disable=C0116
     parser = argparse.ArgumentParser(
         prog="Merlin Examples",
         description=banner_small,
@@ -57,14 +59,14 @@ def setup_argparse():
     return parser
 
 
-def main():
+def main():  # pylint: disable=C0116
     try:
         parser = setup_argparse()
         args = parser.parse_args()
         setup_logging(logger=LOG, log_level=DEFAULT_LOG_LEVEL, colors=True)
         args.func(args)
         sys.exit()
-    except Exception as ex:
+    except Exception as ex:  # pylint: disable=W0718
         print(ex)
         sys.exit(1)
 
