@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -27,6 +27,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 ###############################################################################
+"""This module handles expanding variables in the merlin spec"""
 
 import logging
 from collections import ChainMap
@@ -123,10 +124,10 @@ def expand_env_vars(spec):
         if isinstance(section, str):
             return expandvars(expanduser(section))
         if isinstance(section, dict):
-            for k, v in section.items():
-                if k in ["cmd", "restart"]:
+            for key, val in section.items():
+                if key in ["cmd", "restart"]:
                     continue
-                section[k] = recurse(v)
+                section[key] = recurse(val)
         elif isinstance(section, list):
             for i, elem in enumerate(deepcopy(section)):
                 section[i] = recurse(elem)
@@ -164,10 +165,10 @@ def determine_user_variables(*user_var_dicts):
             raise ValueError(f"Cannot reassign value of reserved word '{key}'! Reserved words are: {RESERVED}.")
         new_val = str(val)
         if contains_token(new_val):
-            for determined_key in determined_results.keys():
+            for determined_key, determined_val in determined_results.items():
                 var_determined_key = var_ref(determined_key)
                 if var_determined_key in new_val:
-                    new_val = new_val.replace(var_determined_key, determined_results[determined_key])
+                    new_val = new_val.replace(var_determined_key, determined_val)
         new_val = expandvars(expanduser(new_val))
         determined_results[key.upper()] = new_val
     return determined_results
@@ -217,6 +218,9 @@ def parameter_substitutions_for_cmd(glob_path, sample_paths):
     return substitutions
 
 
+# There's similar code inside study.py but the whole point of this function is to not use
+# the MerlinStudy object so we disable this pylint error
+# pylint: disable=duplicate-code
 def expand_spec_no_study(filepath, override_vars=None):
     """
     Get the expanded text of a spec without creating
@@ -239,6 +243,9 @@ def expand_spec_no_study(filepath, override_vars=None):
     return expand_by_line(spec_text, evaluated_uvars)
 
 
+# pylint: enable=duplicate-code
+
+
 def get_spec_with_expansion(filepath, override_vars=None):
     """
     Return a MerlinSpec with overrides and expansion, without
