@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -37,18 +37,22 @@ import json
 import logging
 import os
 import shlex
+from copy import deepcopy
+from datetime import timedelta
 from io import StringIO
 
 import yaml
 from maestrowf.specification import YAMLSpecification
 
 from merlin.spec import all_keys, defaults
+from merlin.utils import repr_timedelta
 
 
 LOG = logging.getLogger(__name__)
 
 
-class MerlinSpec(YAMLSpecification):
+# Pylint complains we have too many instance attributes but it's fine
+class MerlinSpec(YAMLSpecification):  # pylint: disable=R0902
     """
     This class represents the logic for parsing the Merlin yaml
     specification.
@@ -67,8 +71,9 @@ class MerlinSpec(YAMLSpecification):
             column_labels: [X0, X1]
     """
 
-    def __init__(self):
-        super(MerlinSpec, self).__init__()
+    # Pylint says this call to super is useless but we'll leave it in case we want to add to __init__ in the future
+    def __init__(self):  # pylint: disable=W0246
+        super().__init__()
 
     @property
     def yaml_sections(self):
@@ -123,32 +128,50 @@ class MerlinSpec(YAMLSpecification):
         return result
 
     @classmethod
-    def load_specification(cls, filepath, suppress_warning=True):
-        LOG.info("Loading specification from path: %s", filepath)
+    def load_specification(cls, path, suppress_warning=True):
+        """
+        Load in a spec file and create a MerlinSpec object based on its' contents.
+
+        :param `cls`: The class reference (like self)
+        :param `path`: A path to the spec file we're loading in
+        :param `suppress_warning`: A bool representing whether to warn the user about unrecognized keys
+        :returns: A MerlinSpec object
+        """
+        LOG.info("Loading specification from path: %s", path)
         try:
-            # Load the YAML spec from the filepath
-            with open(filepath, "r") as data:
+            # Load the YAML spec from the path
+            with open(path, "r") as data:
                 spec = cls.load_spec_from_string(data, needs_IO=False, needs_verification=True)
-        except Exception as e:
+        except Exception as e:  # pylint: disable=C0103
             LOG.exception(e.args)
             raise e
 
         # Path not set in _populate_spec because loading spec with string
         # does not have a path so we set it here
-        spec.path = filepath
-        spec.specroot = os.path.dirname(spec.path)
+        spec.path = path
+        spec.specroot = os.path.dirname(spec.path)  # pylint: disable=W0201
 
         if not suppress_warning:
             spec.warn_unrecognized_keys()
         return spec
 
     @classmethod
-    def load_spec_from_string(cls, string, needs_IO=True, needs_verification=False):
+    def load_spec_from_string(cls, string, needs_IO=True, needs_verification=False):  # pylint: disable=C0103
+        """
+        Read in a spec file from a string (or stream) and create a MerlinSpec object from it.
+
+        :param `cls`: The class reference (like self)
+        :param `string`: A string or stream of the file we're reading in
+        :param `needs_IO`: A bool representing whether we need to turn the string into a file
+                           object or not
+        :param `needs_verification`: A bool representing whether we need to verify the spec
+        :returns: A MerlinSpec object
+        """
         LOG.debug("Creating Merlin spec object...")
         # Create and populate the MerlinSpec object
         data = StringIO(string) if needs_IO else string
         spec = cls._populate_spec(data)
-        spec.specroot = None
+        spec.specroot = None  # pylint: disable=W0201
         spec.process_spec_defaults()
         LOG.debug("Merlin spec object created.")
 
@@ -158,6 +181,18 @@ class MerlinSpec(YAMLSpecification):
             spec.verify()
             LOG.debug("Merlin spec verified.")
 
+        # Convert the walltime value back to HMS if PyYAML messed with it
+        for _, section in spec.yaml_sections.items():
+            # Section is a list for the study block
+            if isinstance(section, list):
+                for step in section:
+                    if "walltime" in step and isinstance(step["walltime"], int):
+                        step["walltime"] = repr_timedelta(timedelta(seconds=step["walltime"]))
+            # Section is a dict for all other blocks
+            if isinstance(section, dict):
+                if "walltime" in section and isinstance(section["walltime"], int):
+                    section["walltime"] = repr_timedelta(timedelta(seconds=section["walltime"]))
+
         return spec
 
     @classmethod
@@ -179,12 +214,12 @@ class MerlinSpec(YAMLSpecification):
         try:
             spec = yaml.load(data, yaml.FullLoader)
         except AttributeError:
-            LOG.warn(
+            LOG.warning(
                 "PyYAML is using an unsafe version with a known "
                 "load vulnerability. Please upgrade your installation "
                 "to a more recent version!"
             )
-            spec = yaml.load(data)
+            spec = yaml.load(data, yaml.Loader)
         LOG.debug("Successfully loaded specification: \n%s", spec["description"])
 
         # Load in the parts of the yaml that are the same as Maestro's
@@ -198,11 +233,11 @@ class MerlinSpec(YAMLSpecification):
 
         # Reset the file pointer and load the merlin block
         data.seek(0)
-        merlin_spec.merlin = MerlinSpec.load_merlin_block(data)
+        merlin_spec.merlin = MerlinSpec.load_merlin_block(data)  # pylint: disable=W0201
 
         # Reset the file pointer and load the user block
         data.seek(0)
-        merlin_spec.user = MerlinSpec.load_user_block(data)
+        merlin_spec.user = MerlinSpec.load_user_block(data)  # pylint: disable=W0201
 
         return merlin_spec
 
@@ -262,7 +297,7 @@ class MerlinSpec(YAMLSpecification):
                         )
                         raise ValueError(error_msg)
 
-        except Exception:
+        except Exception:  # pylint: disable=W0706
             raise
 
     def verify_merlin_block(self, schema):
@@ -288,28 +323,12 @@ class MerlinSpec(YAMLSpecification):
         YAMLSpecification.validate_schema("batch", self.batch, schema)
 
         # Additional Walltime checks in case the regex from the schema bypasses an error
-        if "walltime" in self.batch:
-            if self.batch["type"] == "lsf":
-                LOG.warning("The walltime argument is not available in lsf.")
-            else:
-                try:
-                    err_msg = "Walltime must be of the form SS, MM:SS, or HH:MM:SS."
-                    walltime = self.batch["walltime"]
-                    if len(walltime) > 2:
-                        # Walltime must have : if it's not of the form SS
-                        if ":" not in walltime:
-                            raise ValueError(err_msg)
-                        else:
-                            # Walltime must have exactly 2 chars between :
-                            time = walltime.split(":")
-                            for section in time:
-                                if len(section) != 2:
-                                    raise ValueError(err_msg)
-                except Exception:
-                    raise
+        if self.batch["type"] == "lsf" and "walltime" in self.batch:
+            LOG.warning("The walltime argument is not available in lsf.")
 
     @staticmethod
     def load_merlin_block(stream):
+        """Loads in the merlin block of the spec file"""
         try:
             merlin_block = yaml.safe_load(stream)["merlin"]
         except KeyError:
@@ -324,6 +343,7 @@ class MerlinSpec(YAMLSpecification):
 
     @staticmethod
     def load_user_block(stream):
+        """Loads in the user block of the spec file"""
         try:
             user_block = yaml.safe_load(stream)["user"]
         except KeyError:
@@ -331,6 +351,7 @@ class MerlinSpec(YAMLSpecification):
         return user_block
 
     def process_spec_defaults(self):
+        """Fills in the default values if they aren't there already"""
         for name, section in self.sections.items():
             if section is None:
                 setattr(self, name, {})
@@ -354,8 +375,28 @@ class MerlinSpec(YAMLSpecification):
         if self.merlin["resources"]["workers"] is None:
             self.merlin["resources"]["workers"] = {"default_worker": defaults.WORKER}
         else:
-            for worker, vals in self.merlin["resources"]["workers"].items():
-                MerlinSpec.fill_missing_defaults(vals, defaults.WORKER)
+            # Gather a list of step names defined in the study
+            all_workflow_steps = self.get_study_step_names()
+            # Create a variable to track the steps assigned to workers
+            worker_steps = []
+
+            # Loop through each worker and fill in the defaults
+            for _, worker_settings in self.merlin["resources"]["workers"].items():
+                MerlinSpec.fill_missing_defaults(worker_settings, defaults.WORKER)
+                worker_steps.extend(worker_settings["steps"])
+
+            if "all" in worker_steps:
+                steps_that_need_workers = []
+            else:
+                # Figure out which steps still need workers
+                steps_that_need_workers = list(set(all_workflow_steps) - set(worker_steps))
+
+            # If there are still steps remaining that haven't been assigned a worker yet,
+            # assign the remaining steps to the default worker. If all the steps still need workers
+            # (i.e. no workers were assigned) then default workers' steps should be "all" so we skip this
+            if steps_that_need_workers and (steps_that_need_workers != all_workflow_steps):
+                self.merlin["resources"]["workers"]["default_worker"] = defaults.WORKER
+                self.merlin["resources"]["workers"]["default_worker"]["steps"] = steps_that_need_workers
         if self.merlin["samples"] is not None:
             MerlinSpec.fill_missing_defaults(self.merlin["samples"], defaults.SAMPLES)
 
@@ -370,13 +411,13 @@ class MerlinSpec(YAMLSpecification):
         existing ones.
         """
 
-        def recurse(result, defaults):
-            if not isinstance(defaults, dict):
+        def recurse(result, recurse_defaults):
+            if not isinstance(recurse_defaults, dict):
                 return
-            for key, val in defaults.items():
+            for key, val in recurse_defaults.items():
                 # fmt: off
                 if (key not in result) or (
-                    (result[key] is None) and (defaults[key] is not None)
+                    (result[key] is None) and (recurse_defaults[key] is not None)
                 ):
                     result[key] = val
                 else:
@@ -387,6 +428,7 @@ class MerlinSpec(YAMLSpecification):
 
     # ***Unsure if this method is still needed after adding json schema verification***
     def warn_unrecognized_keys(self):
+        """Checks if there are any unrecognized keys in the spec file"""
         # check description
         MerlinSpec.check_section("description", self.description, all_keys.DESCRIPTION)
 
@@ -397,7 +439,7 @@ class MerlinSpec(YAMLSpecification):
         MerlinSpec.check_section("env", self.environment, all_keys.ENV)
 
         # check parameters
-        for param, contents in self.globals.items():
+        for _, contents in self.globals.items():
             MerlinSpec.check_section("global.parameters", contents, all_keys.PARAMETER)
 
         # check steps
@@ -416,13 +458,14 @@ class MerlinSpec(YAMLSpecification):
         # user block is not checked
 
     @staticmethod
-    def check_section(section_name, section, all_keys):
-        diff = set(section.keys()).difference(all_keys)
+    def check_section(section_name, section, known_keys):
+        """Checks a section of the spec file to see if there are any unrecognized keys"""
+        diff = set(section.keys()).difference(known_keys)
 
         # TODO: Maybe add a check here for required keys
 
         for extra in diff:
-            LOG.warn(f"Unrecognized key '{extra}' found in spec section '{section_name}'.")
+            LOG.warning(f"Unrecognized key '{extra}' found in spec section '{section_name}'.")
 
     def dump(self):
         """
@@ -434,11 +477,11 @@ class MerlinSpec(YAMLSpecification):
             result = result.replace("\n\n\n", "\n\n")
         try:
             yaml.safe_load(result)
-        except Exception as e:
-            raise ValueError(f"Error parsing provenance spec:\n{e}")
+        except Exception as e:  # pylint: disable=C0103
+            raise ValueError(f"Error parsing provenance spec:\n{e}") from e
         return result
 
-    def _dict_to_yaml(self, obj, string, key_stack, tab, newline=True):
+    def _dict_to_yaml(self, obj, string, key_stack, tab):
         """
         The if-else ladder for sorting the yaml string prettification of dump().
         """
@@ -449,12 +492,13 @@ class MerlinSpec(YAMLSpecification):
 
         if isinstance(obj, str):
             return self._process_string(obj, lvl, tab)
-        elif isinstance(obj, bool):
+        if isinstance(obj, bool):
             return str(obj).lower()
-        elif not (isinstance(obj, list) or isinstance(obj, dict)):
-            return obj
-        else:
-            return self._process_dict_or_list(obj, string, key_stack, lvl, tab)
+        if isinstance(obj, list):
+            return self._process_list(obj, string, key_stack, lvl, tab)
+        if isinstance(obj, dict):
+            return self._process_dict(obj, string, key_stack, lvl, tab)
+        return obj
 
     def _process_string(self, obj, lvl, tab):
         """
@@ -465,55 +509,74 @@ class MerlinSpec(YAMLSpecification):
             obj = "|\n" + tab * (lvl + 1) + ("\n" + tab * (lvl + 1)).join(split)
         return obj
 
-    def _process_dict_or_list(self, obj, string, key_stack, lvl, tab):
+    def _process_list(self, obj, string, key_stack, lvl, tab):  # pylint: disable=R0913
         """
-        Processes lists and dicts for _dict_to_yaml() in the dump() method.
+        Processes lists for _dict_to_yaml() in the dump() method.
         """
-        from copy import deepcopy
-
-        list_offset = 2 * " "
-        if isinstance(obj, list):
-            n = len(obj)
-            use_hyphens = key_stack[-1] in ["paths", "sources", "git", "study"] or key_stack[0] in ["user"]
-            if not use_hyphens:
-                string += "["
-            else:
-                string += "\n"
-            for i, elem in enumerate(obj):
-                key_stack = deepcopy(key_stack)
-                key_stack.append("elem")
-                if use_hyphens:
-                    string += (lvl + 1) * tab + "- " + str(self._dict_to_yaml(elem, "", key_stack, tab)) + "\n"
-                else:
-                    string += str(self._dict_to_yaml(elem, "", key_stack, tab, newline=(i != 0)))
-                    if n > 1 and i != len(obj) - 1:
-                        string += ", "
-                key_stack.pop()
-            if not use_hyphens:
-                string += "]"
-        # must be dict
+        num_entries = len(obj)
+        use_hyphens = key_stack[-1] in ["paths", "sources", "git", "study"] or key_stack[0] in ["user"]
+        if not use_hyphens:
+            string += "["
         else:
-            if len(key_stack) > 0 and key_stack[-1] != "elem":
-                string += "\n"
-            i = 0
-            for k, v in obj.items():
-                key_stack = deepcopy(key_stack)
-                key_stack.append(k)
-                if len(key_stack) > 1 and key_stack[-2] == "elem" and i == 0:
-                    # string += (tab * (lvl - 1))
-                    string += ""
-                elif "elem" in key_stack:
-                    string += list_offset + (tab * lvl)
-                else:
-                    string += tab * (lvl + 1)
-                string += str(k) + ": " + str(self._dict_to_yaml(v, "", key_stack, tab)) + "\n"
-                key_stack.pop()
-                i += 1
+            string += "\n"
+        for i, elem in enumerate(obj):
+            key_stack = deepcopy(key_stack)
+            key_stack.append("elem")
+            if use_hyphens:
+                string += (lvl + 1) * tab + "- " + str(self._dict_to_yaml(elem, "", key_stack, tab)) + "\n"
+            else:
+                string += str(self._dict_to_yaml(elem, "", key_stack, tab))
+                if num_entries > 1 and i != len(obj) - 1:
+                    string += ", "
+            key_stack.pop()
+        if not use_hyphens:
+            string += "]"
         return string
 
+    def _process_dict(self, obj, string, key_stack, lvl, tab):  # pylint: disable=R0913
+        """
+        Processes dicts for _dict_to_yaml() in the dump() method
+        """
+        list_offset = 2 * " "
+        if len(key_stack) > 0 and key_stack[-1] != "elem":
+            string += "\n"
+        i = 0
+        for key, val in obj.items():
+            key_stack = deepcopy(key_stack)
+            key_stack.append(key)
+            if len(key_stack) > 1 and key_stack[-2] == "elem" and i == 0:
+                # string += (tab * (lvl - 1))
+                string += ""
+            elif "elem" in key_stack:
+                string += list_offset + (tab * lvl)
+            else:
+                string += tab * (lvl + 1)
+            string += str(key) + ": " + str(self._dict_to_yaml(val, "", key_stack, tab)) + "\n"
+            key_stack.pop()
+            i += 1
+        return string
+
+    def get_step_worker_map(self):
+        """
+        Creates a dictionary with step names as keys and a list of workers
+        associated with each step as values. The inverse of get_worker_step_map().
+        """
+        steps = self.get_study_step_names()
+        step_worker_map = {step_name: [] for step_name in steps}
+        for worker_name, worker_val in self.merlin["resources"]["workers"].items():
+            # Case 1: worker doesn't have specific steps
+            if "all" in worker_val["steps"]:
+                for step_name in step_worker_map:
+                    step_worker_map[step_name].append(worker_name)
+            # Case 2: worker has specific steps
+            else:
+                for step in worker_val["steps"]:
+                    step_worker_map[step].append(worker_name)
+        return step_worker_map
+
     def get_task_queues(self):
         """Returns a dictionary of steps and their corresponding task queues."""
-        from merlin.config.configfile import CONFIG
+        from merlin.config.configfile import CONFIG  # pylint: disable=C0415
 
         steps = self.get_study_steps()
         queues = {}
@@ -540,8 +603,8 @@ class MerlinSpec(YAMLSpecification):
                 else:
                     task_queues = [queues[steps]]
             except KeyError:
-                nl = "\n"
-                LOG.error(f"Invalid steps '{steps}'! Try one of these (or 'all'):\n{nl.join(queues.keys())}")
+                newline = "\n"
+                LOG.error(f"Invalid steps '{steps}'! Try one of these (or 'all'):\n{newline.join(queues.keys())}")
                 raise
         return sorted(set(task_queues))
 
@@ -555,6 +618,7 @@ class MerlinSpec(YAMLSpecification):
         return shlex.quote(queues)
 
     def get_worker_names(self):
+        """Builds a list of workers"""
         result = []
         for worker in self.merlin["resources"]["workers"]:
             result.append(worker)
