@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -202,18 +202,12 @@ class DAG:
         for group in list_of_groups_of_chains:
             for chain in group:
                 for task_name in chain:
-
                     if self.num_children(task_name) == 1 and task_name != "_source":
-
                         child = self.children(task_name)[0]
 
-                        if self.num_parents(child) == 1:
-
-                            if self.compatible_merlin_expansion(child, task_name):
-
-                                self.find_chain(child, list_of_groups_of_chains).remove(child)
-
-                                chain.append(child)
+                        if self.num_parents(child) == 1 and self.compatible_merlin_expansion(child, task_name):
+                            self.find_chain(child, list_of_groups_of_chains).remove(child)
+                            chain.append(child)
 
         new_list = [[chain for chain in group if len(chain) > 0] for group in list_of_groups_of_chains]
         new_list_2 = [group for group in new_list if len(group) > 0]
