@@ -1,12 +1,12 @@
 ###############################################################################
-# Copyright (c) 2022, Lawrence Livermore National Security, LLC.
+# Copyright (c) 2023, Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory
 # Written by the Merlin dev team, listed in the CONTRIBUTORS file.
 # <merlin@llnl.gov>
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.9.0.
+# This file is part of Merlin, Version: 1.10.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -56,7 +56,7 @@ except ImportError:
 
 LOG = logging.getLogger(__name__)
 ARRAY_FILE_FORMATS = ".npy, .csv, .tab"
-DEFAULT_FLUX_VERSION = "0.13"
+DEFAULT_FLUX_VERSION = "0.48.0"
 
 
 def get_user_process_info(user=None, attrs=None):
@@ -78,8 +78,7 @@ def get_user_process_info(user=None, attrs=None):
 
     if user == "all_users":
         return [p.info for p in psutil.process_iter(attrs=attrs)]
-    else:
-        return [p.info for p in psutil.process_iter(attrs=attrs) if user in p.info["username"]]
+    return [p.info for p in psutil.process_iter(attrs=attrs) if user in p.info["username"]]
 
 
 def check_pid(pid, user=None):
@@ -91,8 +90,8 @@ def check_pid(pid, user=None):
         all processes
     """
     user_processes = get_user_process_info(user=user)
-    for p in user_processes:
-        if int(p["pid"]) == pid:
+    for process in user_processes:
+        if int(process["pid"]) == pid:
             return True
     return False
 
@@ -149,12 +148,14 @@ def is_running(name, all_users=False):
     if all_users:
         cmd[1] = "aux"
 
+    # pylint: disable=consider-using-with
     try:
-        ps = subprocess.Popen(cmd, stdout=subprocess.PIPE, encoding="utf8").communicate()[0]
+        process_status = subprocess.Popen(cmd, stdout=subprocess.PIPE, encoding="utf8").communicate()[0]
     except TypeError:
-        ps = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
+        process_status = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
+    # pylint: enable=consider-using-with
 
-    if name in ps:
+    if name in process_status:
         return True
 
     return False
@@ -178,12 +179,32 @@ def regex_list_filter(regex, list_to_filter, match=True):
 
     :return `new_list`
     """
-    r = re.compile(regex)
+    r = re.compile(regex)  # pylint: disable=C0103
     if match:
         return list(filter(r.match, list_to_filter))
     return list(filter(r.search, list_to_filter))
 
 
+def apply_list_of_regex(regex_list, list_to_filter, result_list, match=False):
+    """
+    Take a list of regex's, apply each regex to a list we're searching through,
+    and append each result to a result list.
+
+    :param `regex_list`: A list of regular expressions to apply to the list_to_filter
+    :param `list_to_filter`: A list that we'll apply regexs to
+    :param `result_list`: A list that we'll append results of the regex filters to
+    :param `match`: A bool where when true we use re.match for applying the regex,
+                    when false we use re.search for applying the regex.
+    """
+    for regex in regex_list:
+        filter_results = set(regex_list_filter(regex, list_to_filter, match))
+
+        if not filter_results:
+            LOG.warning(f"No regex match for {regex}.")
+        else:
+            result_list += filter_results
+
+
 def load_yaml(filepath):
     """
     Safely read a yaml file.
@@ -232,7 +253,7 @@ def load_array_file(filename, ndmin=2):
 
     # Don't change binary-stored numpy arrays; just check dimensions
     if protocol == "npy":
-        array = np.load(filename)
+        array = np.load(filename, allow_pickle=True)
         if array.ndim < ndmin:
             LOG.error(
                 f"Array in {filename} has fewer than the required \
@@ -240,9 +261,9 @@ def load_array_file(filename, ndmin=2):
             )
     # Make sure text files load as strings with minimum number of dimensions
     elif protocol == "csv":
-        array = np.loadtxt(filename, delimiter=",", ndmin=ndmin, dtype=np.str)
+        array = np.loadtxt(filename, delimiter=",", ndmin=ndmin, dtype=str)
     elif protocol == "tab":
-        array = np.loadtxt(filename, ndmin=ndmin, dtype=np.str)
+        array = np.loadtxt(filename, ndmin=ndmin, dtype=str)
     else:
         raise TypeError(
             f"{protocol} is not a valid array file extension.\
@@ -268,7 +289,7 @@ def determine_protocol(fname):
 
 
 @contextmanager
-def cd(path):
+def cd(path):  # pylint: disable=C0103
     """
     TODO
     """
@@ -282,7 +303,7 @@ def cd(path):
 
 def pickle_data(filepath, content):
     """Dump content to a pickle file"""
-    with open(filepath, "w") as f:
+    with open(filepath, "w") as f:  # pylint: disable=C0103
         pickle.dump(content, f)
 
 
@@ -343,22 +364,22 @@ def nested_dict_to_namespaces(dic):
     return recurse(new_dic)
 
 
-def nested_namespace_to_dicts(ns):
+def nested_namespace_to_dicts(namespaces):
     """Code for recursively converting namespaces of namespaces
     into dictionaries instead.
     """
 
-    def recurse(ns):
-        if not isinstance(ns, SimpleNamespace):
-            return ns
-        for key, val in list(ns.__dict__.items()):
-            setattr(ns, key, recurse(val))
-        return ns.__dict__
+    def recurse(namespaces):
+        if not isinstance(namespaces, SimpleNamespace):
+            return namespaces
+        for key, val in list(namespaces.__dict__.items()):
+            setattr(namespaces, key, recurse(val))
+        return namespaces.__dict__
 
-    if not isinstance(ns, SimpleNamespace):
-        raise TypeError(f"{ns} is not a SimpleNamespace")
+    if not isinstance(namespaces, SimpleNamespace):
+        raise TypeError(f"{namespaces} is not a SimpleNamespace")
 
-    new_ns = deepcopy(ns)
+    new_ns = deepcopy(namespaces)
     return recurse(new_ns)
 
 
@@ -371,50 +392,73 @@ def get_flux_version(flux_path, no_errors=False):
     """
     cmd = [flux_path, "version"]
 
-    ps = None
+    process = None
 
     try:
-        ps = subprocess.Popen(cmd, stdout=subprocess.PIPE, encoding="utf8").communicate()
-    except FileNotFoundError as e:
+        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, encoding="utf8").communicate()  # pylint: disable=R1732
+    except FileNotFoundError as e:  # pylint: disable=C0103
         if not no_errors:
             LOG.error(f"The flux path {flux_path} canot be found")
             LOG.error("Suppress this error with no_errors=True")
             raise e
 
     try:
-        flux_ver = re.search(r"\s*([\d.]+)", ps[0]).group(1)
-    except (ValueError, TypeError) as e:
+        flux_ver = re.search(r"\s*([\d.]+)", process[0]).group(1)
+    except (ValueError, TypeError) as e:  # pylint: disable=C0103
         if not no_errors:
             LOG.error("The flux version cannot be determined")
             LOG.error("Suppress this error with no_errors=True")
             raise e
-        else:
-            flux_ver = DEFAULT_FLUX_VERSION
-            LOG.warning(f"Using syntax for default version: {flux_ver}")
+        flux_ver = DEFAULT_FLUX_VERSION
+        LOG.warning(f"Using syntax for default version: {flux_ver}")
 
     return flux_ver
 
 
 def get_flux_cmd(flux_path, no_errors=False):
     """
-    Return the flux command as string
+    Return the flux run command as string
 
     :param `flux_path`: the full path to the flux bin
     :param `no_errors`: a flag to determine if this a test run to ignore errors
     """
-    # The default is for flux version >= 0.13,
+    # The default is for flux version >= 0.48.x
     # this may change in the future.
-    flux_cmd = "flux mini run"
+    flux_cmd = "flux run"
 
     flux_ver = get_flux_version(flux_path, no_errors=no_errors)
 
     vers = [int(n) for n in flux_ver.split(".")]
+    if vers[0] == 0 and vers[1] < 48:
+        flux_cmd = "flux mini run"
+
     if vers[0] == 0 and vers[1] < 13:
         flux_cmd = "flux wreckrun"
 
     return flux_cmd
 
 
+def get_flux_alloc(flux_path, no_errors=False):
+    """
+    Return the flux alloc command as string
+
+    :param `flux_path`: the full path to the flux bin
+    :param `no_errors`: a flag to determine if this a test run to ignore errors
+    """
+    # The default is for flux version >= 0.48.x
+    # this may change in the future.
+    flux_alloc = f"{flux_path} alloc"
+
+    flux_ver = get_flux_version(flux_path, no_errors=no_errors)
+
+    vers = [int(n) for n in flux_ver.split(".")]
+
+    if vers[0] == 0 and vers[1] < 48:
+        flux_alloc = f"{flux_path} mini alloc"
+
+    return flux_alloc
+
+
 def check_machines(machines):
     """
     Return a True if the current machine is in the list of machines.
@@ -465,40 +509,39 @@ def convert_to_timedelta(timestr: Union[str, int]) -> timedelta:
     nfields = len(timestr.split(":"))
     if nfields > 4:
         raise ValueError(f"Cannot convert {timestr} to a timedelta. Valid format: days:hours:minutes:seconds.")
-    _, d, h, m, s = (":0" * 10 + timestr).rsplit(":", 4)
+    _, d, h, m, s = (":0" * 10 + timestr).rsplit(":", 4)  # pylint: disable=C0103
     tdelta = timedelta(days=int(d), hours=int(h), minutes=int(m), seconds=int(s))
     return tdelta
 
 
-def _repr_timedelta_HMS(td: timedelta) -> str:
+def _repr_timedelta_HMS(time_delta: timedelta) -> str:  # pylint: disable=C0103
     """Represent a timedelta object as a string in hours:minutes:seconds"""
-    hours, remainder = divmod(td.total_seconds(), 3600)
+    hours, remainder = divmod(time_delta.total_seconds(), 3600)
     minutes, seconds = divmod(remainder, 60)
     hours, minutes, seconds = int(hours), int(minutes), int(seconds)
     return f"{hours:02d}:{minutes:02d}:{seconds:02d}"
 
 
-def _repr_timedelta_FSD(td: timedelta) -> str:
+def _repr_timedelta_FSD(time_delta: timedelta) -> str:  # pylint: disable=C0103
     """Represent a timedelta as a flux standard duration string, using seconds.
 
     flux standard duration (FSD) is a floating point number with a single character suffix: s,m,h or d.
     This uses seconds for simplicity.
     """
-    fsd = f"{td.total_seconds()}s"
+    fsd = f"{time_delta.total_seconds()}s"
     return fsd
 
 
-def repr_timedelta(td: timedelta, method: str = "HMS") -> str:
+def repr_timedelta(time_delta: timedelta, method: str = "HMS") -> str:
     """Represent a timedelta object as a string using a particular method.
 
     method - HMS: 'hours:minutes:seconds'
     method - FSD: flux standard duration: 'seconds.s'"""
     if method == "HMS":
-        return _repr_timedelta_HMS(td)
-    elif method == "FSD":
-        return _repr_timedelta_FSD(td)
-    else:
-        raise ValueError("Invalid method for formatting timedelta! Valid choices: HMS, FSD")
+        return _repr_timedelta_HMS(time_delta)
+    if method == "FSD":
+        return _repr_timedelta_FSD(time_delta)
+    raise ValueError("Invalid method for formatting timedelta! Valid choices: HMS, FSD")
 
 
 def convert_timestring(timestring: Union[str, int], format_method: str = "HMS") -> str:
